use Test::More tests => 1;

BEGIN {
  use_ok('Rubric::Entry::Formatter::KwikiFormatish');
}

diag( "Testing Rubric::Entry::Formatter::KwikiFormatish $Rubric::Entry::Formatter::KwikiFormatish::VERSION" );
